@@ -3,6 +3,9 @@ from typing import Any, Dict, List
 import logging
 import json
 
+from django.conf import settings as dj_settings
+from django.urls import resolve
+
 from tokko_auth.util import beautiful_errors, auth_is_enable
 from tokko_auth.exceptions import NamespaceNotMatch
 from tokko_auth.helpers import AuthorizationHelper
@@ -41,6 +44,11 @@ class AuthMiddlewareBase:
     i_am_testing: bool = None
     expected_exception = None
     auth_request_property = "tokko_auth"
+    default_public_views = [
+        "/api/schema/",
+        "/api/schema/graphql/",
+        "/api/graphql/json/"
+    ]
 
     def __init__(self, get_response, i_am_testing=False):
         self.i_am_testing = i_am_testing
@@ -59,7 +67,13 @@ class AuthMiddlewareBase:
         logger.warning(f'{self}. AfterView Callback not configured')
         return response
 
+    def is_public(self, request) -> bool:
+        public_views = getattr(dj_settings, "PUBLIC_VIEWS", []) + self.default_public_views
+        return request.path_info in public_views
+
     def __call__(self, request):
+        if self.is_public(request):
+            return self.get_response(request)
         if auth_is_enable() or self.i_am_testing:
             try:
                 request = self.before_view(request)
@@ -102,6 +116,10 @@ class HasJWTMiddleware(AuthMiddlewareBase, AuthorizationHelper):
     """Request has JWT middleware"""
 
     def before_view(self, request) -> Any:
+        current_url = resolve(request.path_info).url_name
+        if current_url in getattr(dj_settings, "PUBLIC_VIEWS", []):
+            print(f"Omitting {current_url}. Public View.")
+            return request
         token = self.get_token(request.headers)
         auth = MinimalAuth(
             token,
